@@ -59,7 +59,7 @@ namespace Oxygen
         { return isAnimated( object, point, mode ) ? data( object, mode ).data()->opacity( point ) : AnimationData::OpacityInvalid; }
 
         //* enability
-        virtual void setEnabled( bool value )
+        void setEnabled( bool value )
         {
             BaseEngine::setEnabled( value );
             _hoverData.setEnabled( value );
@@ -67,7 +67,7 @@ namespace Oxygen
         }
 
         //* duration
-        virtual void setDuration( int value )
+        void setDuration( int value )
         {
             BaseEngine::setDuration( value );
             _hoverData.setDuration( value );
@@ -77,7 +77,7 @@ namespace Oxygen
         public Q_SLOTS:
 
         //* remove widget from map
-        virtual bool unregisterWidget( QObject* object )
+        bool unregisterWidget( QObject* object )
         {
             if( !object ) return false;
             bool found = false;
